var gulp = require('gulp'),
    template = require('gulp-template'),
    rename = require('gulp-rename'),
    conflict = require("gulp-conflict"),
    path = require("path"),
    chalk = require('chalk');

function _templateBuilder(promptAnswers, options) {
    gulp.src(__dirname + options.templateSource)
        .pipe(template(promptAnswers))
        .pipe(rename(promptAnswers.fileName + options.fileExtn))
        .pipe(conflict(options.base + options.dir + '/' + options.folderName))
        .pipe(gulp.dest(options.base + options.dir + '/' + options.folderName));
    if (options.finish) {
        gulp.on('finish', function() {
            console.log("\n" + chalk.green("Success! - Component Created"));
            process.exit(1);
        });
    }
}

function componentGenerator(promptAnswers, options) {

    options.dir = options.appDir;
    options.folderName = promptAnswers.fileName;

    if (promptAnswers.testCase) {
        options.templateSource = '/templates/javascript/component/*.spec.js';
        options.fileExtn = '.spec.js';
        _templateBuilder(promptAnswers, options);
    }

    options.templateSource = '/templates/javascript/component/*.controller.js';
    options.fileExtn = '.controller.js';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/component/*.component.js';
    options.fileExtn = '.component.js';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/component/*.html';
    options.fileExtn = '.html';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/component/*.scss';
    options.fileExtn = '.scss';
    options.finish = true;
    _templateBuilder(promptAnswers, options);

}

function directiveGenerator(promptAnswers, options) {

    options.dir = options.appDir;
    options.folderName = promptAnswers.fileName;

    if (promptAnswers.testCase) {
        options.templateSource = '/templates/javascript/directive/*.spec.js';
        options.fileExtn = '.spec.js';
        _templateBuilder(promptAnswers, options);
    }

    options.templateSource = '/templates/javascript/directive/*.controller.js';
    options.fileExtn = '.controller.js';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/directive/*.directive.js';
    options.fileExtn = '.directive.js';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/directive/*.html';
    options.fileExtn = '.html';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/directive/*.scss';
    options.fileExtn = '.scss';
    options.finish = true;
    _templateBuilder(promptAnswers, options);

}

function ngServiceGenerator(promptAnswers, options) {

    options.dir = options.serviceDir;
    options.folderName = promptAnswers.fileName;

    if (promptAnswers.testCase) {
        options.templateSource = '/templates/javascript/service/*.spec.js';
        options.fileExtn = '.spec.js';
        _templateBuilder(promptAnswers, options);
    }

    options.templateSource = '/templates/javascript/service/*.service.js';
    options.fileExtn = '.js';
    _templateBuilder(promptAnswers, options);

    options.templateSource = '/templates/javascript/service/*.module.js';
    options.fileExtn = '.module.js';
    options.finish = true;
    _templateBuilder(promptAnswers, options);

}

function mockServiceGenerator(promptAnswers, options) {

    options.dir = options.serviceDir;
    options.folderName = '';

    if (promptAnswers.testCase) {
        options.templateSource = '/templates/javascript/mocks/*.spec.js';
        options.fileExtn = '.spec.js';
        _templateBuilder(promptAnswers, options);
    }

    options.templateSource = '/templates/javascript/mocks/template.mocks.js';
    options.fileExtn = '.js';
    options.finish = true;
    _templateBuilder(promptAnswers, options);
}

var generators = {
    componentGenerator: componentGenerator,
    directiveGenerator: directiveGenerator,
    ngServiceGenerator: ngServiceGenerator,
    mockServiceGenerator: mockServiceGenerator
};

module.exports = generators;
