var inquirer = require('inquirer'),
    _ = require('underscore.string'),
    async = require("async"),
    clear = require("cli-clear"),
    util = require('./util.js'),
    generators = require('./generators.js');

function appStart() {
    async.series([
        function(callback) {
            clear();
            var Nyancat = require('nyansole'),
                nyancat = (new Nyancat()).start();
            setTimeout(function() {
                nyancat.end();
                callback();
            }, 500);
        },
        function(callback) {
            var welcome = require('./locales/welcome.js');
            console.log(welcome);
            callback();
        },
        function(callback) {
            util = require('./util.js');
            inquirer.prompt(util.optionListTerminal(), function(params) {
                angularScaffold.promptUser(params.options);
                callback();
            });
        }
    ]);
}

// Function call just for development
if (process.mainModule.filename.indexOf("node_modules") === -1) {
    appStart();
}

function promptUser(optionList) {
    if (optionList === 'ngComponent') {
        inquirer.prompt(util.componentTerminal(), function(params) {
            promptAnswers = {
                scriptAppName: params.module,
                className: _.camelize(params.fileName),
                fileName: _.slugify(params.fileName),
                testCase: params.spec,
                pathTemplates: params.pathTemplates,
            };
            var options = util.getGlobalOptions(promptAnswers.pathTemplates);
            generators.componentGenerator(promptAnswers, options);
        });
    }

    if (optionList === 'ngDirective') {
        inquirer.prompt(util.directiveTerminal(), function(params) {
            promptAnswers = {
                scriptAppName: params.module,
                className: _.camelize(params.fileName),
                fileName: _.slugify(params.fileName),
                testCase: params.spec,
                pathTemplates: params.pathTemplates,
            };
            var options = util.getGlobalOptions(promptAnswers.pathTemplates);
            generators.directiveGenerator(promptAnswers, options);
        });
    }

    if (optionList === 'ngService') {
        inquirer.prompt(util.ngServiceTerminal(), function(params) {
            var serviceName = _textfinder(params.fileName.toLowerCase(), 'service');
            promptAnswers = {
                className: _.camelize(serviceName),
                fileName: _.slugify(serviceName),
                testCase: params.spec,
                pathTemplates: params.pathTemplates,
            };
            var options = util.getGlobalOptions(promptAnswers.pathTemplates);
            generators.ngServiceGenerator(promptAnswers, options);
        });
    }

    if (optionList === 'mockService') {
        inquirer.prompt(util.mockServiceTerminal(), function(params) {
            promptAnswers = {
                className: _.camelize(params.fileName),
                fileName: _.slugify(params.fileName),
                pathTemplates: params.pathTemplates,
            };
            var options = util.getGlobalOptions(promptAnswers.pathTemplates);
            generators.mockServiceGenerator(promptAnswers, options);
        });
    }
}

function _textfinder(fileName, textToAppend) {
    if (fileName.indexOf(textToAppend) >= 0) {
        return fileName;
    } else {
        return fileName + ' ' + textToAppend;
    }
}

var angularScaffold = {
    appStart: appStart,
    promptUser: promptUser
};

module.exports = angularScaffold;
